<img src="assets/logo_complete_svg.svg" width="300" height="300" />

## Overview
![GitHub](https://img.shields.io/github/license/Khushiyant/quasar?&style=for-the-badge)
![Python](https://img.shields.io/badge/Made%20With%20Python-lightblue?logo=python&&style=for-the-badge&logoColor=black)

Quasar is python package that can be used for smell detection along with detailed report in various formats such as html, pdf, etc. 



## License

This project is licensed under the GPL License - see the [LICENSE](LICENSE) file for details